---
slug: us-social-token-law
title: Social Tokens and US Securities Law
tags: [legal]
authors: [mark,noah]
---

# US Securities Law and Social Tokens

Strata Social Tokens give content creators the tools they need to easily create and manage their own personalized cryptocurrency. This comes with unequaled opportunities for monetization and community engagement.

New opportunities often expose us to risk, especially where we lack information. If you are a creator based in the US, it is important that you stay on the right side of US securities laws. We created this guide as a primer for everything you need to know before you mint your first Social Token.

:::caution Disclaimer
Securities can be a complex and evolving area of law. This post is intended to provide general educational information, but is not legal advice. Its content was overseen by lawyers retained by Wum.bo and Strata, but they are not your lawyers. If you have any questions about securities laws, contact an attorney licensed in your jurisdiction for advice on what *you* should do to stay legal.
:::

## TL;DR; 

Many token projects have had success reducing the risk of being deemed a security by focusing on one of the following features:

**Provide non-financial benefits to limit risk of security status**

If you're based in the US or offer your Social Tokens to US individuals, you should set up your Social Token to provide rewards or perks to your fans, but nothing that could be considered profit (such as an appreciation of capital or a share in your earnings). You should likely avoid even hinting that the coins could appreciate in value or "pay off" somehow. Be straightforward. Let your fans know that your Strata Social Tokens are a great way to show their appreciation for what you do, and can carry some nifty perks as well — maybe an exclusive video or a chance to buy tickets to a show early. But nothing more.

Your aim should be for your tokens to be consumed; the more these tokens are meant to be exchanged for status, perks, goods, or services, the less they look like a security. This aligns well with the royalties mechanic — you receive royalties when tokens are being transacted. Look to provide value in exchange for holding or paying tokens.

**Ensure any increase in value of Social Token is the result of community activity**

If purchasers of your token are not motivated by your entrepreneurial activities, the token may not be considered a security. The best example is an unclaimed token, or a token you have claimed but are not actively participating in. In this case, the value of the token is derived from community efforts (the fans).The value can also be derived from applications like Wum.bo, which is a platform built on Strata Protocol that brings Strata Social Tokens directly to social networks. Wum.bo is allowing users to gain utility from using the token; such as displaying it in tweet replies as a symbol of support. In this case, an argument can be made that the value of the token is derived from Wum.bo, the Strata Ecosystem, and the fans.

# US Securities Law

So, what is a security, anyway, and why is it a big deal?

The [Securities Act of 1933](https://www.law.cornell.edu/uscode/text/15/chapter-2A) and the [Securities Exchange Act of 1934](https://www.law.cornell.edu/uscode/text/15/chapter-2B) are the bedrock of securities laws in the United States. Enacted in the wake of "Black Tuesday" and the [stock market crash of 1929](https://en.wikipedia.org/wiki/Wall_Street_Crash_of_1929), they impose strict regulations on the sale of "securities," defined broadly to include a wide range of instruments, including "investment contracts."

But what is an "investment contract?" In [*SEC v. W. J. Howey Co.*](https://scholar.google.com/scholar_case?case=12975052269830471754), 328 U.S. 293 (1946), the U.S. Supreme Court formulated what came to be called the *Howey* test: a set of four factors. If all four factors are present in a given instrument, it's an investment contract (and thus a security). They are:

1.  An investment of money,
2.  In a common enterprise,
3.  With a reasonable expectation of profit,
4.  Derived solely from the entrepreneurial or managerial efforts of others.

When considering whether a given instrument is an investment contract, it's important not to look only at the form and terms of the instrument itself, but also on its context and circumstances.

Whether or not a given instrument is a security is critically important. It's [generally illegal](https://www.law.cornell.edu/uscode/text/15/77e) (outside certain exemptions) to offer or sell securities across state lines unless they're properly registered---and the registration requirements can be burdensome. But if an instrument isn't a security, those requirements don't usually apply. If you're considering offering a Social Token or similar crypto coin or token, whether or not your coin is a security is a critical distinction: it can mean the difference between spending substantial time and expense dealing with red tape or not (with the possibility of Securities and Exchange Commission ("SEC") [administrative action](https://www.sec.gov/news/press-release/2017-227), a lawsuit, or criminal penalties for failure to comply). 

## The *Howey* test and crypto: more than you wanted to know.

If you plan to offer a Social Token, you'll want to ensure that it's not a security under U.S. law by using the *Howey* test to evaluate its status (and remember, *all* four factors need to be met for it to be a security). Let's take a closer look at the four *Howey* factors to see what they mean for creators using crypto to connect to their fans.

### Factor 1: An investment of money

Do you plan to allow fans (or, for that matter, anyone) to purchase your Social Tokens? That's probably an investment of money for *Howey* purposes, which [does not need to take the form of cash](https://scholar.google.com/scholar_case?case=18122359483577127601#p574). U.S. dollars qualify, but so do other exchanges of value, such as Bitcoin, Bitcoin Cash, Sol, or [Ethereum](https://www.sec.gov/litigation/investreport/34-81207.pdf#page=11).

### Factor 2: In a common enterprise

This is somewhat tricker to consider: [courts in the U.S. are actually split](https://kb.osu.edu/bitstream/handle/1811/71438/OSLJ_V72N1_0059.pdf#page=10) with respect to [what test should be applied](https://blj.ucdavis.edu/archives/vol-5-no-2/why-the-common-enterprise-test.html) to determine whether the common enterprise factor of *Howey* has been met. Because it's difficult or impossible to determine beforehand which court's rule applies, we need to look at all of them to be on the safe side.

Most courts require a finding of "horizontal commonality," which generally requires that the funds or assets of purchasers are pooled and that such purchasers proportionally share profits and risks associated with the enterprise. Generally, [horizontal commonality is present](https://scholar.google.com/scholar_case?case=2208670512106548076#p87) "when the fortunes of each investor depend upon the profitability of the enterprise as a whole," often combined with a pro-rata distribution of profits.

So if you're a creator planning to issue a Social Token, the key question is whether you are pooling the assets of the Coin Sale purchasers in a common enterprise. Consider: are the rewards associated with your Social Tokens going to go up or down in value for each individual Coin holder in line with your entire Coin ecosystem? If so, you may have horizontal commonality, which in some courts, would meet the second *Howey* factor.

A less popular approach involves determining whether there is "vertical commonality," which typically focuses on the relationship between the investment contract's promotors and the purchasers. Vertical commonality can be further broken down into "broad vertical commonality" and "narrow vertical commonality."

Under [broad vertical commonality](https://scholar.google.com/scholar_case?case=17409364479262407727#p1284), used by some courts, "the investors are dependent upon the expertise or efforts of the investment promoter for their returns." Unlike horizontal commonality, broad vertical commonality can exist even in the absence of other investors in a scheme.

[Narrow vertical commonality](https://scholar.google.com/scholar_case?case=693719772247331481#p1339) (used by the Ninth Circuit Court of Appeals) examines the relationship between the purchaser and the promoters and asks whether the fortunes of the investor are inextricably interwoven with and dependent on the efforts and success of a promoter. This test ignores whether funds have been pooled, and can exist on a one-to-one basis between an investor and purchaser.

Under these approaches, when you consider your Social Token, ask yourself: are the rewards associated with your Coins dependent on your expertise or efforts? Or, is the success of any Coin holder in receiving rewards interwoven with and dependent on your own efforts and success? If so, you may have vertical commonality, which in some courts, would meet the second *Howey* factor.

### Factor 3: With a reasonable expectation of profit

The third *Howey* factor is whether purchasers of an investment contract reasonably expect profits. "Profits" has a [limited meaning](https://scholar.google.com/scholar_case?case=17409364479262407727#p1284) under federal securities law, [requiring either](https://scholar.google.com/scholar_case?case=11168754825085710379#p852) the appreciation of investment capital, or a participation in earnings.

In its investigations, the SEC [often examines](https://storage.courtlistener.com/recap/gov.uscourts.nyed.409850/gov.uscourts.nyed.409850.25.0.pdf#page=13) the marketing efforts of the promoters and the materials provided to potential purchasers to ascertain the reasonable expectations of the investors. With regard to crypto currencies and tokens, for instance, the SEC has [focused](https://www.sec.gov/litigation/investreport/34-81207.pdf#page=4) [heavily](https://www.sec.gov/litigation/investreport/34-81207.pdf#page=11) on statements promising a return in the form of profit sharing and capital appreciation of tokens, and [argued in court](https://storage.courtlistener.com/recap/gov.uscourts.nyed.409850/gov.uscourts.nyed.409850.25.0.pdf#page=13) that promotion materials were a critical element in establishing that the investors were expecting profits.

But where a purchaser is motivated primarily by the desire to use or consume the item purchased, [courts have found](https://scholar.google.com/scholar_case?case=11257695012640894231#p1135) that there is no expectation of profit. Under those circumstances, "[securities laws do not apply](https://scholar.google.com/scholar_case?case=11168754825085710379#p852)."

The upshot of this for Social Tokens is that the third factor of the *Howey* test can be avoided (and thus, securities status can be avoided) by ensuring that the coins carry no expectation of profit. The coins should not be marketed as an "investment"---not even subtly or implicitly---and should carry no language that suggests that participants can "grow" or "increase" anything of value from their purchase price, or that they can participate in your earnings as a creator.

If the SEC ever investigates, they'll likely look carefully at the statements you make in promoting your coins. If you watch what you say, and are careful to emphasize that the coins can only be used or consumed---e.g., by trading them in for perks or privileges which are not exchangeable for cash or other cash substitutes---you may stand a better chance of avoiding legal difficulty.

### Factor 4: Derived solely from the entrepreneurial or managerial efforts of others

The fourth *Howey* factor examines whether profits expected by purchasers are derived from the managerial or entrepreneurial efforts of the promoters or a third party. In other words, the [key element is *who*](https://scholar.google.com/scholar_case?case=2857800830304992891#p482) makes the efforts which affect the success or failure of the enterprise: the investor, or someone else.

With regard to digital assets, including cryptocurrency coins and tokens, at least one SEC official has [expressed the view](https://www.sec.gov/news/speech/speech-hinman-061418) that a network that is "sufficiently decentralized ... where purchasers would no longer reasonably expect a person or group to carry out essential managerial or entrepreneurial efforts ... may not represent an investment contract."

This is good news: under this view, most virtual currencies proposed in token offerings are not inherently securities in themselves. Instead, *the nature of the transaction* is what establishes an investment contract. [Potential factors](https://www.sec.gov/news/speech/speech-hinman-061418) in this determination include the nature of the currency's distribution and whether such distribution mechanisms are tailored towards use or consumption, the nature of a project's promoters and whether they are raising excessive funds, and whether there are information asymmetries.

Adding to this, in 2019, the SEC Strategic Hub for Innovation and Financial Technology released guidance providing a [framework](https://www.sec.gov/corpfin/framework-investment-contract-analysis-digital-assets) (the "Framework") for analyzing whether certain digital assets, including cryptocurrency coins and tokens, are "investment contracts" under the *Howey* test. The Framework does not constitute new law and is non-binding, but it currently serves as the most comprehensive look at the SEC's approach to reviewing certain digital assets. It also introduces the concept of an "Active Participant" with regard to the fourth factor of the *Howey* test.

The Framework defines an [Active Participant](https://www.sec.gov/files/dlt-framework.pdf#page=3) ("AP") as "a promoter, sponsor, or other third party (or affiliated group of third parties)," and looks at the group collectively when determining if their "essential managerial efforts ... affect the success of the enterprise, and investors reasonably expect to derive profit from those efforts." In other words, an AP is someone whose efforts investors reasonably rely on for their profit.

The Framework provides characteristics of what it means to rely on the "efforts of others:" the more of these characteristics that are satisfied, the higher the likelihood that the fourth factor of the *Howey* test is satisfied. These characteristics include, among others:

-   An AP is responsible for the development, improvement (or enhancement), operation, or promotion of the network. 
-   There are essential tasks or responsibilities performed and expected to be performed by an AP, rather than an unaffiliated, dispersed community of network users (a "decentralized" network). 
-   An AP creates or supports a market for, or the price of, the digital asset.
-   An AP has a lead or central role in the direction of the ongoing development of the network or the digital asset.
-   An AP has a continuing managerial role in making decisions about or exercising judgment concerning the network or the characteristics or rights the digital asset represents.
-   Purchasers would reasonably expect the AP to undertake efforts to promote its own interests and enhance the value of the network or digital asset.

That's a lot to take in. But the upshot is that if participants in your Social Token system reasonably expect to make a profit, the extent to which you or someone working with you manages, operates, or oversees your coin ecosystem could determine whether investors reasonably expect your efforts to be what generates that profit. And if they do, the fourth factor of the *Howey* test may be satisfied, which puts your coin one step closer to being classed as a security.

## Wrapping up

As you can see, evaluating whether your Social Token is a security under U.S. laws is tricky business. The regulations are intricate and can be challenging, even for trained experts.

But remember: because all four *Howey* factors are required for your Social Token to be a an "investment contract" (and thus, a security), avoiding meeting any one of the factors will generally be sufficient to avoid security status.

Probably the easiest to avoid is the third factor: the expectation of profit. Due to the narrow definition of "profit" under securities laws, if you set up your Social Token to provide rewards or perks to your fans, but nothing that could be considered profit (such as an appreciation of capital or a share in your earnings), you may likely avoid accidentally creating a security.

Because any investigation would look at *your* statements and those of anyone else working with you in promoting the coin, it's probably a good idea to avoid making broad, sweeping announcements. You should likely avoid even hinting that the coins could appreciate in value or "pay off" somehow. Be straightforward. Let your fans know that your Strata Social Tokens are a great way to show their appreciation for what you do, and can carry some nifty perks as well — maybe an exclusive video or a chance to buy tickets to a show early. But nothing more.

Your tokens are meant to be consumed and traded; this aligns well with the royalties mechanic — you receive royalties when tokens are being transacted. Look to allow people to trade tokens in exchange for perks, goods, or services. Purchases should be motivated primarily by the desire to use or consume the item purchased.

Another way to position your token is to asses where the value of the token is derived. If purchasers of your token are not motivated by your entrepreneurial activities, the token may not be considered a security. The best example is an unclaimed token, or a token you have claimed but are not actively participating in. In this cases, the value of the token is derived from community efforts (the fans). The value is also derived from applications like Wum.bo allowing users to gain utility from using the token as a status symbol. In this case, an argument can be made that the value of the token is derived from Wum.bo, Strata, and the fans. If your token is "sufficiently decentralized," in that it is governed by the community, you may have an argument that it is not a security.

This can all seem overwhelming, but you are already on the right track by reading through this document. If you pay careful attention and think ahead, you may find yourself in a better position to avoid inadvertently violating federal securities laws than another creator who didn't do their homework.


Happy building!
